==> atmosphere-compat-weblogic-0.5.1-sources.jar: weblogic/servlet/http/AbstractAsyncServlet.java <==
/*
 * 
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 2007-2008 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 */

package weblogic.servlet.http;

import java.io.IOException;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;

/**
 * Fake support for Weblogic. Weblogic jars aren't public and not available with
 * any repository, so fake them.
 * 
 * @author Jeanfrancois Arcand
 */
public abstract class AbstractAsyncServlet extends HttpServlet {
    
    protected abstract boolean doRequest(RequestResponseKey rrk)
            throws IOException, ServletException;

    protected abstract void doResponse(RequestResponseKey rrk, Object o) 
            throws IOException, ServletException;

    protected abstract void doTimeout(RequestResponseKey rrk) 
            throws IOException, ServletException;
    
    public final static void notify(RequestResponseKey rrk, Object context) throws IOException{
        return;
    }
}

==> atmosphere-compat-weblogic-0.6.2-sources.jar: weblogic/servlet/http/AbstractAsyncServlet.java <==
/*
 * 
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 2007-2008 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 */
package weblogic.servlet.http;

import org.eclipse.jetty.websocket.WebSocketServlet;

import javax.servlet.ServletException;
import java.io.IOException;

/**
 * Fake support for Weblogic. Weblogic jars aren't public and not available with
 * any repository, so fake them.
 *
 * @author Jeanfrancois Arcand
 */
public abstract class AbstractAsyncServlet extends WebSocketServlet {

    protected abstract boolean doRequest(RequestResponseKey rrk)
            throws IOException, ServletException;

    protected abstract void doResponse(RequestResponseKey rrk, Object o)
            throws IOException, ServletException;

    protected abstract void doTimeout(RequestResponseKey rrk)
            throws IOException, ServletException;

    public final static void notify(RequestResponseKey rrk, Object context) throws IOException {
        return;
    }

}
